==> hls_player-1.0.6.tar.gz: ios/Classes/SwiftHlsPlayerPlugin.swift <==
import Flutter

import UIKit
import AVFoundation
import Foundation
import AVKit

public class SwiftHlsPlayerPlugin: UIViewController, FlutterPlugin {

   let AVPlayerZapping : ViewController_AVPlayer_List = ViewController_AVPlayer_List() ;

  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "hls_player", binaryMessenger: registrar.messenger())
    let instance = SwiftHlsPlayerPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {

        switch call.method {
                            case "initializeVideo":
                            
                                  guard let args = call.arguments else {
                                          result("iOS could not recognize flutter arguments in method: ( \(call.method))") 
                                          return
                                        }

                                      if let myArgs = args as? [String: String],
                                          let url = myArgs["url"] as? String {

                                            
                                                  //Present your ViewController only if its not present to the user currently.
                                                  let AVPlayerVideo : ViewController_AVPlayer_Video = ViewController_AVPlayer_Video() ;
                                                  AVPlayerVideo.isBuild( url, userCompletionHandler: {mensaje, error in
           
                result(mensaje) 
        })
                                        } else {
                                          result(FlutterError(code: "-1", message: "iOS could not extract " + 
                                            "flutter arguments 'url' in method: ( \(call.method))", details: nil))
                                        } 
                break;


               case "initializeZapping":
        
                                      guard let args = call.arguments else {
                                      result("iOS could not recognize flutter arguments in method: ( \(call.method))") 
                                      return
                                    }

                                  if let myArgs = args as? [String: Any],
                                      let canales = myArgs["canales"] as? Array<String>,
                                      let playVideoAtIndex = myArgs["playVideoAtIndex"] as? Int {


                                        //let AVPlayerZapping : ViewController_AVPlayer_List = ViewController_AVPlayer_List() ;
                                        self.AVPlayerZapping.canales = canales
                                        self.AVPlayerZapping.playVideoIndex = playVideoAtIndex


                                        DispatchQueue.main.async { UIApplication.shared.keyWindow?.rootViewController?.present(self.AVPlayerZapping, animated: true, completion: nil);  }
                                                  
                                                  
                                                      // if( AVPlayerZapping.isBeingPresented) {

                                                      //     result(canales)
                                                      // }else{
                                                      //     result(FlutterError(code: "-1", message: "No fue abierto el Controlador \(call.method)", details: nil))
                                                      // }

                                                          result(canales)
                                                        
                                  } else {
                                          result(FlutterError(code: "-1", message: "iOS could not extract " + 
                                            "flutter arguments 'canales' in method: ( \(call.method))", details: nil))
                                  }
 
                        break;



               case "getVideoLink":
        
                              

                             
 

                                                          result(self.AVPlayerZapping.getCurrentLink())
                                                        
                            
 
                        break;
          default:
              result(FlutterMethodNotImplemented)
                
        }
      
       
    }
        


  



}

==> hls_player-1.1.4.tar.gz: ios/Classes/SwiftHlsPlayerPlugin.swift <==
import Flutter

import UIKit
import AVFoundation
import Foundation
import AVKit

public class SwiftHlsPlayerPlugin: UIViewController, FlutterPlugin {

   let AVPlayerZapping : ViewController_AVPlayer_List = ViewController_AVPlayer_List() ;

  public static func register(with registrar: FlutterPluginRegistrar) {
    let channel = FlutterMethodChannel(name: "hls_player", binaryMessenger: registrar.messenger())
    let instance = SwiftHlsPlayerPlugin()
    registrar.addMethodCallDelegate(instance, channel: channel)
  }

  public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {

        switch call.method {
                            case "initializeVideo":
                            
                                  guard let args = call.arguments else {
                                          result("iOS could not recognize flutter arguments in method: ( \(call.method))") 
                                          return
                                        }

                                      if let myArgs = args as? [String: String],
                                          let url = myArgs["url"] {

                                            
                                                  //Present your ViewController only if its not present to the user currently.
                                                  let AVPlayerVideo : ViewController_AVPlayer_Video = ViewController_AVPlayer_Video() ;
                                                  AVPlayerVideo.isBuild( url, userCompletionHandler: {mensaje, error in
           
                result(mensaje) 
        })
                                        } else {
                                          result(FlutterError(code: "-1", message: "iOS could not extract " + 
                                            "flutter arguments 'url' in method: ( \(call.method))", details: nil))
                                        } 
                break;


               case "initializeZapping":
        
                                      guard let args = call.arguments else {
                                      result("iOS could not recognize flutter arguments in method: ( \(call.method))") 
                                      return
                                    }

                                  if let myArgs = args as? [String: Any],
                                      let canales = myArgs["canales"] as? Array<String>,
                                      let playVideoAtIndex = myArgs["playVideoAtIndex"] as? Int {


                                        //let AVPlayerZapping : ViewController_AVPlayer_List = ViewController_AVPlayer_List() ;
                                        
                                        self.AVPlayerZapping.playVideoIndex = playVideoAtIndex
  AVPlayerZapping.jsonCanales = "[{\"studio\":1381,\"titulo\":\"titulo\",\"imagenPath\":\"https://i.ibb.co/hcDwyzx/logo-1565631656.png\",\"descripcion\":\"descripcion\",\"numeroCanal\":1,\"linkReproductor\":\"http://200.23.206.107:18080/canales/miscelaneos/docubox/playlist.m3u8\"},{\"studio\":1382,\"titulo\":\"titulo\",\"imagenPath\":\"https://i.ibb.co/r0w20HX/logo-1567784648.png\",\"descripcion\":\"descripcion\",\"numeroCanal\":2,\"linkReproductor\":\"http://mdstrm.com/video/5a29c07e5522e40a45beb669.m3u8\"},{\"studio\":1383,\"titulo\":\"titulo\",\"imagenPath\":\"https://i.ibb.co/pwg1vpM/logo-1587071125.png\",\"descripcion\":\"descripcion\",\"numeroCanal\":3,\"linkReproductor\":\"http://unlimited1-cl.dps.live/campustv/campustv.smil/playlist.m3u8\"}]";

     

                                        DispatchQueue.main.async { UIApplication.shared.keyWindow?.rootViewController?.present(self.AVPlayerZapping, animated: true, completion: nil);  }
                                                  
                                                  
                                                      // if( AVPlayerZapping.isBeingPresented) {

                                                      //     result(canales)
                                                      // }else{
                                                      //     result(FlutterError(code: "-1", message: "No fue abierto el Controlador \(call.method)", details: nil))
                                                      // }

                                                          result(canales)
                                                        
                                  } else {
                                          result(FlutterError(code: "-1", message: "iOS could not extract " + 
                                            "flutter arguments 'canales' in method: ( \(call.method))", details: nil))
                                  }
 
                        break;



               case "getVideoLink":
        
                              

                             
 

                                                          result(self.AVPlayerZapping.getCurrentLink())
                                                        
                            
 
                        break;
          default:
              result(FlutterMethodNotImplemented)
                
        }
      
       
    }
        


  



}
